@@ -4,6 +4,8 @@ import sys
 PY_VERSION = sys.version_info[:2]
 
 PY_36_PLUS = PY_VERSION >= (3, 6)
+PY_37_PLUS = PY_VERSION >= (3, 7)
+
 
 if PY_VERSION > (3, 0):
 
@@ -23,6 +25,8 @@ if PY_VERSION > (3, 0):
     self_name = '__self__'
     from io import StringIO
     xrange = range
+    from itertools import zip_longest
+    from functools import reduce
 
 else:
 
@@ -42,17 +46,5 @@ else:
     self_name = 'im_self'
     from StringIO import StringIO
     xrange = xrange
-
-try:
-    from mock import call as mock_call
-except ImportError:  # pragma: no cover
-    class MockCall:
-        pass
-    mock_call = MockCall()
-
-try:
-    from unittest.mock import call as unittest_mock_call
-except ImportError:
-    class UnittestMockCall:
-        pass
-    unittest_mock_call = UnittestMockCall()
+    from itertools import izip_longest as zip_longest
+    reduce = reduce
